package com.gmei


import java.io.Serializable

import org.apache.spark.sql.{SaveMode, TiContext}
import org.apache.log4j.{Level, Logger}
import scopt.OptionParser
import com.gmei.lib.AbstractParams
import org.apache.spark.sql.functions.lit

import scala.util.Try



object EsmmData {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev",
                    date: String = GmeiConfig.getMinusNDate(1)
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("EsmmData")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    opt[String]("date")
        .text(s"the date you used")
        .action((x,c) => c.copy(date = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.EsmmData ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }



  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "eagle",tableName = "src_mimas_prod_api_diary_tags")
      ti.tidbMapTable(dbName = "eagle",tableName = "src_zhengxing_api_tag")
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_click")
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_exposure")
      ti.tidbMapTable(dbName = "jerry_test", tableName = "esmm_train_data")


      val max_stat_date = sc.sql(
        s"""
           |select max(stat_date) from esmm_train_data
         """.stripMargin
      )
      val max_stat_date_str = max_stat_date.collect().map(s => s(0).toString).head
      println("max_stat_date_str",max_stat_date_str)
      println("param.date",param.date)
      if (max_stat_date_str != param.date){
        val stat_date = param.date
        println(stat_date)
//        val imp_data = sc.sql(
//          s"""
//             |select distinct stat_date,device_id,city_id as ucity_id,
//             |  cid_id,diary_service_id
//             |from data_feed_exposure
//             |where cid_type = 'diary'
//             |and stat_date ='${stat_date}'
//         """.stripMargin
//        )

        val imp_data = sc.sql(
          s"""
             |select * from
             |(select stat_date,device_id,city_id as ucity_id,cid_id,diary_service_id
             |from data_feed_exposure
             |where cid_type = 'diary'
             |and stat_date ='${stat_date}'
             |group by stat_date,device_id,city_id,cid_id,diary_service_id having count(*) > 1) a
         """.stripMargin
        )
        //      imp_data.show()
        //      println("imp_data.count()")
        //      println(imp_data.count())


        val clk_data = sc.sql(
          s"""
             |select distinct stat_date,device_id,city_id as ucity_id,
             |  cid_id,diary_service_id
             |from data_feed_click
             |where cid_type = 'diary'
             |and stat_date ='${stat_date}'
         """.stripMargin
        )
        //      clk_data.show()
        //      println("clk_data.count()")
        //      println(clk_data.count())



        val imp_data_filter = imp_data.except(clk_data).withColumn("y",lit(0)).withColumn("z",lit(0))
        //      imp_data_filter.createOrReplaceTempView("imp_data_filter")
        //      imp_data_filter.show()
        //      println("imp_data_filter.count()")
        //      println(imp_data_filter.count())


        val stat_date_not = stat_date.replace("-","")
        val cvr_data = sc.sql(
          s"""
             |select distinct
             |  from_unixtime(unix_timestamp(partition_date ,'yyyyMMdd'), 'yyyy-MM-dd') as stat_date,
             |  cl_id as device_id,city_id as ucity_id,
             |  params["referrer_id"] as cid_id,params["business_id"] as diary_service_id
             |from online.tl_hdfs_maidian_view
             |where action='page_view'
             |and partition_date ='${stat_date_not}'
             |and params['page_name'] = 'welfare_detail'
             |and params['referrer'] = 'diary_detail'
         """.stripMargin
        )

        val cvr_data_filter = cvr_data.withColumn("y",lit(1)).withColumn("z",lit(1))
        //      cvr_data_filter.createOrReplaceTempView("cvr_data_filter")
        //      cvr_data_filter.show()
        //      println("cvr_data_filter.count()")
        //      println(cvr_data_filter.count())



        val clk_data_filter =clk_data.except(cvr_data).withColumn("y",lit(1)).withColumn("z",lit(0))
        //      clk_data_filter.createOrReplaceTempView("clk_data_filter")
        //      clk_data_filter.show()
        //      println("clk_data_filter.count()")
        //      println(clk_data_filter.count())


        val union_data = imp_data_filter.union(clk_data_filter).union(cvr_data_filter)
        union_data.createOrReplaceTempView("union_data")
        //      union_data.show()
        //      println("union_data.count()")
        //      println(union_data.count())



        val union_data_clabel = sc.sql(
          s"""
             |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.diary_service_id,a.y,a.z,
             |  c.level1_id as clevel1_id
             |from union_data a
             |left join online.tl_hdfs_diary_tags_view b on a.cid_id=b.diary_id
             |left join online.bl_tag_hierarchy_detail c on b.tag_id=c.id
             |where b.partition_date='${stat_date_not}'
             |and c.partition_date='${stat_date_not}'
         """.stripMargin
        )
        union_data_clabel.createOrReplaceTempView("union_data_clabel")
        //      union_data_clabel.show()

        val union_data_slabel = sc.sql(
          s"""
             |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.diary_service_id,a.y,a.z,a.clevel1_id,
             |  c.level1_id as slevel1_id
             |from union_data_clabel a
             |left join online.tl_meigou_servicetag_view b on a.diary_service_id=b.service_id
             |left join online.bl_tag_hierarchy_detail c on b.tag_id=c.id
             |where b.partition_date='${stat_date_not}'
             |and c.partition_date='${stat_date_not}'
         """.stripMargin
        )
        union_data_slabel.createOrReplaceTempView("union_data_slabel")
        //      union_data_slabel.show()


        val union_data_ccity_name = sc.sql(
          s"""
             |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.diary_service_id,a.y,a.z,a.clevel1_id,a.slevel1_id,
             |  c.name as ccity_name
             |from union_data_slabel a
             |left join src_mimas_prod_api_diary_tags b on a.cid_id=b.diary_id
             |left join src_zhengxing_api_tag c on b.tag_id=c.id
             | where c.tag_type=4
         """.stripMargin
        )
        union_data_ccity_name.createOrReplaceTempView("union_data_ccity_name")
        //      union_data_ccity_name.show()

        val union_data_scity_id = sc.sql(
          s"""
             |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.diary_service_id,a.y,a.z,a.clevel1_id,a.slevel1_id,a.ccity_name,
             |  d.city_id as scity_id
             |from union_data_ccity_name a
             |left join online.tl_meigou_service_view b on a.diary_service_id=b.id
             |left join online.tl_hdfs_doctor_view c on b.doctor_id=c.id
             |left join online.tl_hdfs_hospital_view d on c.hospital_id=d.id
             |where b.partition_date='${stat_date_not}'
             |and c.partition_date='${stat_date_not}'
             |and d.partition_date='${stat_date_not}'
         """.stripMargin
        )
        //      union_data_scity_id.createOrReplaceTempView("union_data_scity_id")
        union_data_scity_id.show()
        GmeiConfig.writeToJDBCTable("jdbc:mysql://10.66.157.22:4000/jerry_test?user=root&password=3SYz54LS9#^9sBvC&rewriteBatchedStatements=true",union_data_scity_id, table="esmm_train_data",SaveMode.Append)

      } else {
        println("esmm_train_data already have param.date data")
      }

      sc.stop()

    }
  }

}


object EsmmPredData {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev"
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("EsmmData")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.EsmmData ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }



  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "eagle",tableName = "src_mimas_prod_api_diary_tags")
      ti.tidbMapTable(dbName = "eagle",tableName = "src_zhengxing_api_tag")
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_exposure")
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_click")
      ti.tidbMapTable("jerry_prod", "nd_device_cid_similarity_matrix")
      ti.tidbMapTable("eagle","ffm_diary_queue")
      ti.tidbMapTable("eagle","search_queue")
      ti.tidbMapTable(dbName = "jerry_test",tableName = "esmm_train_data")
      ti.tidbMapTable("eagle","biz_feed_diary_queue")

      import sc.implicits._

      val yesteday_have_seq = GmeiConfig.getMinusNDate(1)

      //nearby_data
      val raw_data = sc.sql(
        s"""
           |select concat(tmp1.device_id,",",tmp1.city_id) as device_city, tmp1.merge_queue from
           |(select device_id,if(city_id='world','worldwide',city_id) city_id,similarity_cid as merge_queue from nd_device_cid_similarity_matrix
           |union
           |select device_id,if(city_id='world','worldwide',city_id) city_id,native_queue as merge_queue from ffm_diary_queue
           |union
           |select device_id,city_id,search_queue as merge_queue from search_queue) as tmp1
           |where tmp1.device_id in (select distinct device_id from data_feed_click where stat_date='${yesteday_have_seq}')
         """.stripMargin
      )
      raw_data.show()


      val raw_data1 = raw_data.rdd.groupBy(_.getAs[String]("device_city")).map {
        case (device_city, cid_data) =>
          val device_id = Try(device_city.split(",")(0)).getOrElse("")
          val city_id = Try(device_city.split(",")(1)).getOrElse("")
          val cids = Try(cid_data.toSeq.map(_.getAs[String]("merge_queue").split(",")).flatMap(_.zipWithIndex).sortBy(_._2).map(_._1).distinct.take(500).mkString(",")).getOrElse("")
          (device_id,city_id ,s"$cids")
      }.filter(_._3!="").toDF("device_id","city_id","merge_queue")
      raw_data1.createOrReplaceTempView("raw_data1")
      println("nearby_device_count",raw_data1.count())

      val raw_data2 = sc.sql(
        s"""
           |select device_id,city_id as ucity_id,explode(split(merge_queue, ',')) as cid_id from raw_data1
         """.stripMargin
      ).withColumn("label",lit(1))
      raw_data2.createOrReplaceTempView("raw_data2")
      println("nearby_explode_count",raw_data2.count())


      // native_data
      val native_data = sc.sql(
        s"""
           |select distinct a.device_id,a.city_id,b.native_queue from data_feed_exposure a
           |left join (select if(city_id='world','worldwide',city_id) city_id,native_queue from biz_feed_diary_queue) b
           |on a.city_id = b.city_id
           |where a.stat_date='${yesteday_have_seq}' and b.native_queue != ""
         """.stripMargin
      )
      native_data.createOrReplaceTempView("native_data")
      println("native_device_count",native_data.count())

      val native_data1 = sc.sql(
        s"""
           |select device_id,city_id as ucity_id,
           |explode(split(split(native_queue, concat(',',split(native_queue,',')[500]))[0],',')) as cid_id
           |from native_data
         """.stripMargin
      ).withColumn("label",lit(0))
      native_data1.createOrReplaceTempView("native_data1")
      println("native_explode_count",native_data1.count())



      //union
      val union_data = sc.sql(
        s"""
           |select device_id,ucity_id,cid_id,label from native_data1
           |union
           |select device_id,ucity_id,cid_id,label from raw_data2
         """.stripMargin
      )
      union_data.createOrReplaceTempView("raw_data")
      println("union_count",union_data.count())


      //join feat
      val yesteday = GmeiConfig.getMinusNDate(1).replace("-","")
      val sid_data = sc.sql(
        s"""
           |select distinct
           |  from_unixtime(unix_timestamp(partition_date ,'yyyyMMdd'), 'yyyy-MM-dd') as stat_date,
           |  a.device_id,a.ucity_id,a.cid_id,a.label, b.service_id as diary_service_id
           |from raw_data a
           |left join online.ml_community_diary_updates b on a.cid_id = b.diary_id
           |where b.partition_date = '${yesteday}'
         """.stripMargin
      )
//      sid_data.show()
      println(sid_data.count())

      val sid_data_label = sid_data.withColumn("y",lit(0)).withColumn("z",lit(0))
      sid_data_label.createOrReplaceTempView("union_data")


      val union_data_clabel = sc.sql(
        s"""
           |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.label,a.diary_service_id,a.y,a.z,
           |  c.level1_id as clevel1_id
           |from union_data a
           |left join online.tl_hdfs_diary_tags_view b on a.cid_id=b.diary_id
           |left join online.bl_tag_hierarchy_detail c on b.tag_id=c.id
           |where b.partition_date='${yesteday}'
           |and c.partition_date='${yesteday}'
         """.stripMargin
      )
      union_data_clabel.createOrReplaceTempView("union_data_clabel")
      //      union_data_clabel.show()

      val union_data_slabel = sc.sql(
        s"""
           |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.label,a.diary_service_id,a.y,a.z,a.clevel1_id,
           |  c.level1_id as slevel1_id
           |from union_data_clabel a
           |left join online.tl_meigou_servicetag_view b on a.diary_service_id=b.service_id
           |left join online.bl_tag_hierarchy_detail c on b.tag_id=c.id
           |where b.partition_date='${yesteday}'
           |and c.partition_date='${yesteday}'
         """.stripMargin
      )
      union_data_slabel.createOrReplaceTempView("union_data_slabel")
      //      union_data_slabel.show()


      val union_data_ccity_name = sc.sql(
        s"""
           |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.label,a.diary_service_id,a.y,a.z,a.clevel1_id,a.slevel1_id,
           |  c.name as ccity_name
           |from union_data_slabel a
           |left join src_mimas_prod_api_diary_tags b on a.cid_id=b.diary_id
           |left join src_zhengxing_api_tag c on b.tag_id=c.id
           | where c.tag_type=4
         """.stripMargin
      )
      union_data_ccity_name.createOrReplaceTempView("union_data_ccity_name")
      //      union_data_ccity_name.show()

      val union_data_scity_id = sc.sql(
        s"""
           |select a.stat_date,a.device_id,a.ucity_id,a.cid_id,a.label,a.diary_service_id,a.y,a.z,a.clevel1_id,a.slevel1_id,a.ccity_name,
           |  d.city_id as scity_id
           |from union_data_ccity_name a
           |left join online.tl_meigou_service_view b on a.diary_service_id=b.id
           |left join online.tl_hdfs_doctor_view c on b.doctor_id=c.id
           |left join online.tl_hdfs_hospital_view d on c.hospital_id=d.id
           |where b.partition_date='${yesteday}'
           |and c.partition_date='${yesteday}'
           |and d.partition_date='${yesteday}'
         """.stripMargin
      )
      union_data_scity_id.createOrReplaceTempView("union_data_scity_id")

      val union_data_scity_id2 = sc.sql(
        s"""
           |select device_id,cid_id,first(stat_date) stat_date,first(ucity_id) ucity_id,first(label) label,first(diary_service_id)diary_service_id,first(y) y,
           |first(z) z,first(clevel1_id) clevel1_id,first(slevel1_id) slevel1_id,first(ccity_name) ccity_name,first(scity_id) scity_id
           |from union_data_scity_id
           |group by device_id,cid_id
         """.stripMargin
      )


      //      union_data_scity_id.createOrReplaceTempView("union_data_scity_id")
      println(union_data_scity_id2.count())
      GmeiConfig.writeToJDBCTable("jdbc:mysql://10.66.157.22:4000/jerry_test?user=root&password=3SYz54LS9#^9sBvC&rewriteBatchedStatements=true",union_data_scity_id2, table="esmm_pre_data",SaveMode.Overwrite)




      sc.stop()

    }
  }

}

object GetDiaryPortrait {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev",
                    date: String = GmeiConfig.getMinusNDate(1)
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("EsmmData")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    opt[String]("date")
      .text(s"the date you used")
      .action((x,c) => c.copy(date = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.EsmmData ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }



  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_click")

      val stat_date = param.date.replace("-","")

      val diary_tag = sc.sql(
        s"""
           |select c.diary_id,
           |		concat_ws(';',collect_set(cast(c.level1_id as string))) as level1_ids,
           |		concat_ws(';',collect_set(cast(c.level2_id as string))) as level2_ids,
           |		concat_ws(';',collect_set(cast(c.level3_id as string))) as level3_ids from
           |	(select a.diary_id,b.level1_id,b.level2_id,b.level3_id
           |		from online.tl_hdfs_diary_tags_view a
           |		left join online.bl_tag_hierarchy_detail b
           |		on a.tag_id = b.id
           |		where a.partition_date = '${stat_date}'
           |		and b.partition_date = '${stat_date}') c
           |	group by c.diary_id
         """.stripMargin
      )
      diary_tag.show()
      println(diary_tag.count())

      GmeiConfig.writeToJDBCTable(diary_tag,"diary_feat",SaveMode.Overwrite)


      sc.stop()

    }
  }

}

object GetDevicePortrait {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev",
                    date: String = GmeiConfig.getMinusNDate(1)
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("EsmmData")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    opt[String]("date")
      .text(s"the date you used")
      .action((x,c) => c.copy(date = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.EsmmData ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }



  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_click")
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "diary_feat")
      import sc.implicits._

      val stat_date = param.date.replace("-","")

      val device_search_tag = sc.sql(
        s"""
           |select c.device_id,c.stat_date,c.level1_id,count(c.level1_id) as level1_count
           |from (select
           |		a.cl_id as device_id,a.partition_date as stat_date,
           |		COALESCE(a.params['diary_id'], a.params['business_id'], 0) as cid_id,
           |		b.level1_ids as level1_id
           |	from online.tl_hdfs_maidian_view a
           |	left join diary_feat b
           |	on COALESCE(a.params['diary_id'], a.params['business_id'], 0) = b.diary_id
           |	where
           |    b.level1_ids is not null and
           |		a.partition_date = '${stat_date}'
           |		and (a.action = 'on_click_diary_card' or (a.action="full_stack_click_video_card_full_screen_play" and a.params["card_type"]="diary"))) c
           |group by c.device_id,c.level1_id,c.stat_date
         """.stripMargin
      )
      device_search_tag.show()
      println(device_search_tag.count())

      device_search_tag.createOrReplaceTempView("tag_count")

      val max_count_tag = sc.sql(
      s"""
         |select a.device_id,a.stat_date,a.level1_id as max_level1_id,a.level1_count as max_level1_count
         |from tag_count a
         |inner join
         |(select device_id,max(level1_count) as max_count from tag_count group by device_id) b
         |on a.level1_count = b.max_count and a.device_id = b.device_id
       """.stripMargin
    )
//        .rdd.map(x => (x(0).toString,x(1).toString,x(2).toString,x(3).toString))
//      max_count_tag.foreachPartition(GmeiConfig.updateDeviceFeat)
//
//      max_count_tag.take(10).foreach(println)
//      println(max_count_tag.count())

      //drop duplicates
      val max_count_tag_rdd = max_count_tag.rdd.groupBy(_.getAs[String]("device_id")).map {
        case (device_id,data) =>
          val stat_date = data.map(_.getAs[String]("stat_date")).head
          val max_level1_id = data.map(_.getAs[String]("max_level1_id")).head.toString
          val max_level1_count = data.map(_.getAs[Long]("max_level1_count")).head.toString
          (device_id,stat_date,max_level1_id,max_level1_count)
      }.filter(_._1!=null)


      max_count_tag_rdd.foreachPartition(GmeiConfig.updateDeviceFeat)
      max_count_tag_rdd.take(10).foreach(println)
      println(max_count_tag_rdd.count())

      sc.stop()

    }
  }

}

object GetLevelCount {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev",
                    path: String = null
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("EsmmData")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    opt[String]("path")
      .text(s"the path you used")
      .action((x,c) => c.copy(path = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.EsmmData ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }



  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "data_feed_click")
      ti.tidbMapTable(dbName = "jerry_prod",tableName = "diary_feat")


      import sc.implicits._
      val stat_date = GmeiConfig.getMinusNDate(1).replace("-","")

//      val diary_queue = sc.read.json(param.path).rdd.map(x => x(0).toString).distinct().collect().toList.mkString(",")
      val diary_queue = "16122519,16375466,16375466,16033788,16258558,15573353,15521916,15306456,16294414,16317847,15419823,15519458,16108382,15904499,15572044,16107161,15750663,16108382,16140950,16425343,16089403,16266581,15628919,16399988,15750663,16035120,16283654,15521916,16234732,16035120,16419166,15361021,16015427,16059552,16323686,16424738,16232729,16211979,15385035,16397281,15580990,16300613,16084175,15856889,15748007,16108382,16406366,16244538,16255792,15856889,15572042,16084175,16261624,16083671,16107161,16056557,15302734,16424856,15430398,15572010,16246122,16122519,15458127,15594296,15950864,16101582,14492168,15491360,15458127,15572010,16108382,15519424,16138136,16116832,15506175,15967572,16246122,16424945,15890925,15584320,15592807,16088936,15458127,16391945,15299111,15912093,16157187,16266581,16419503,16142120,16142120,16323686,15881144,15527308,15458127,15572010,15519517,15976127,15506175,15901687,15294642,15461348,15856889,16406450,15644562,16101582,16123614,16139896,15329072,15712726,16192534,16182426,15764467,16192490,16439970,15962087,16108827,16241362,15329072,16192545,16059730,16240858,15326870,15384194,16201896,16110474,16133070,16045719,16427366,15195678,16135042,15757822,15322104,16248906,16311772,16230190,16419272,15991079,15506175,15329072,16237438,15195678,16237438,15593754,16133070,16262436,16270019,15329072,16266780,16108935,16135045,16102074,16059730,15329072,16240858,16108856,16133070,16267518,16101956,15329072,15991079,16184602,16100313,15329072,16439970,16075276,16140876,15326870,16260384,16133070,16104906,16133070,15336838,15376733,16140876,16133070,15936749,16313256,16100313,15329072,16262436,16110474,15336542,14689637,16260384,16133070,16427366,16262627,16129543,15340149,15730362,16332310,14689637,14689637,16237438,15584320,15199558,15623506,16331243,16267518,16355079,14689637,16195948,16277593,16260384,16174089,15340149,16126229,16235777,16423988,16243002,15515359,16192545,16427366,16174346,16066280,16131096,16274053,15364347,16110474,15863392,15730476,16244688,16248966,15506175,15863392,16427366,16262436,15570354,16187037,16129543,15346185,16248906,15383889,16436167,16184574,16121223,16237438,15730478,16238796,16262436,16236969,16124625,15650970,16329972,15632808,16251221,16266753,16439970,16201896,16428307,16198971,16071405,16267518,15860870,15732027,16197096,15732027,15730266,16439970,15294215,15389249,15389249,15863342,16294781,15429632,16430487,16430487,16430487,15649199,16430487,16248906,16133070,16430934,15592280,16277593,16260384,16430487,15361461,16430487,16258793,16430487,16437405,16430487,15361461,16430487,16430487,16294781,16430487,16121377,16430487,16135045,16059552,16437405,16437405,15954746,15650970,16121377,15732027,16280425,15659286,15732027,16437405,16437405,16437405,16437405,15659286,16121377,16234869,16234869,16234869,16234869,16258793,16437405,16140950,15572010,16107161,16419272,16015427,15423535,15966159,15398719,15519517,15827317,16323686,15426010,15418950,15597614,16266581,16426770,16056557,15349114,15827317,15961993,16424945,15650970,16299587,16129543,16157187,15491159,16266581,16232729,15573353,16116832,15584320,16204980,15515359,16140950,15649199,15253194,16140026,16056557,15521916,16157187,15594296,16437405,16296887,15506175,15519458,16084313,15481272,15519424,15841996,15834886,15505388,16397281,15398056,16084313,16107161,16084313,15481272,16375466,15545409,15521916,15385553,15360927,16266340,15890407,15946834,15597614,15609095,16084313,15646229,16300020,16266581,15621245,15912093,15481272,16419166,16015427,15950864,15505372,15827317,15842031,16376782,15890407,15505388,15564307,16116953,16294414,15748007,15468379,16225627,15271888,16269882,16101582,16059552,15720101,16211979,16282308,15603296,16107161,16107161,15592807,15461348,16050175,16233792,15564307,16041397,16118595,15750663,15489962,15385035,15338446,15970190,16194812,15750663,15419823,15572010,16437405,14971705,16267518,15527308,15425026,16424738,16111482,15827317,16261624,15300599,16193282,16437405,15271888,15946834,15527308,15890407,15572010,16397053,15491360,16437405,16116854,16375466,15306456,16129543,14492168,15506175,15302622,15976127,16266581,16425343,16397053,16323686,15294642,15890407,16437405,15481272,16142120,16304243,15594747,15384914,16035120,15572044,16211130,16122519,15712411,15299111,15572010,16084175,15594747,16084175,16116869,15732027,16376782,15426010,15338446,15877749,16425141,15764357,15644562,16083671,16425364,16123026,15477602,15901687,15594747,16297085,16298666,15458127,16108382,16299168,16258615,16142120,16108382,15271888,16088936,15423793,15519511,15468379,16269126,15747009,16084561,15271888,16255792,16084561,16204934,15967572,15625223,15895704,16244538,15570251,16317847,16258786,15860650,15423793,15458127,15397912,16145806,16419503,16283654,15594747,16116818,16089403,15458127,16108382,16437405,15423793,15475055,16426770,15328957,15361235,16301612,16297765,16138136,15505372,16437405,16419346,15338446,15890925,16300613,15458127,16108382,15423793,15361021,16399988,16424856,16422648,16035120,16437405,15895704,16085403,16115168,16096830,16282308,16297085,15338446,16056557,16056557,16015427,15649199,16258615,15506175,15302622,16116832,16157187,16140950,15385035,16140950,15418950,15527308,15572042,16246122,16258786,15748007,16194812,15489962,16301612,16116818,15890407,16127449,15646229,16246122,16266581,16376782,16244538,16300613,15970190,15860650,15976127,15338446,16157187,16115168,15644562,15519517,16304243,16088936,15712411,16225627,15461348,15842031,16323686,15895704,15895704,16228125,15950864,15584320,16422648,16419503,16424856,16269126,15621245,15506175,16399988,15609095,15328957,16233792,16323686,15597614,15890407,16116953,16096830,16122519,15338446,15603296,16425343,15572010,15572010,16118595,15572010,15572010,16035495,16375466,16419166,15967572,15475055,15300599,15890925,16269882,16419346,16111482,16338429,16298666,15371151,15527308,15890407,16015427,15564307,16127449,15890407,16424738,15491159,15564307,14971705,15573339,15912093,16267518,16426770,15299111,15349114,16085403,15519472,16425364,16375466,16297765,16426770,15720101,15398719,15519424,15597614,15764357,16300020,16376782,16266581,16266581,15519458,16084313,15545409,16084313,16129543,16084313,16084313,15419823,16055221,15519511,16266581,16129543,11022630,15486474,11022630,16197096,15486474,15656660,11022630,16376782,15397912,16376782,9389133,9389133,9389133,16246141,9389133,9389133,9389133,9389133,15954409,9389133,15491159,9389133,9389133,9389133,9389133,9389133,9389133,16215222,16101582,12694412,16204965,15636685,16089403,16265011,16323686,15338446,15361235,15793271,16411631,16427366,15564307,16410463,15599246,16265011,15793271,16116953,15992295,16381642,16157187,16425364,16241932,16228265,15912093,15793271,16407835,14314647,16101582,16399442,15545409,14314647,16129543,16228265,16376782,15793271,14314647,15793271,15515359,16292817,15970190,16375466,16187641,16266581,15750626,16419272,16015427,15841996,15793271,16398744,16121397,16104921,16177932,16401353,15793271,15793271,15599246,16265011,15572010,16297085,16193658,15793271,16140026,15793271,16212122,15764357,16266581,16210963,15901687,16140950,15565485,15992214,15955709,15646746,15992295,15793271,15565466,16430932,15793271,16427366,16298017,15565485,16154317,16116869,15778306,16381661,15950864,15397912,14314647,15793271,16419346,15793271,16251094,16427366,15644562,16401353,16154317,16323686,15338446,16244385,16308965,16204294,16228470,16297765,15599246,15621245,15793271,16177932,15891357,15572010,16434659,16228265,15793271,16177932,15572010,16428203,16129543,16395901,16424738,15646746,16401353,16425343,15635473,15778306,15475055,16084313,14314647,16300020,16265011,16221150,16015427,15732739,15713026,15891357,15976127,16140350,16123026,16046949,14314647,14971705,15565485,15950394,16228265,16296887,16088936,15572010,16298666,15639719,14492168,15656660,15423535,16116306,14314647,15793271,15398056,16084175,16116306,15732027,16013432,15793271,15793271,16118595,16376782,16427366,16187641,15773814,16140950,14314647,16204294,15565485,16272706,16187641,16101582,16265011,15646746,15954409,16270443,15793271,16084175,15427520,15957063,16269126,16426770,15966159,15992214,16308965,16269882,16177932,15426723,16187641,16211979,15338446,16381779,16157187,16274302,16375466,16116306,16430932,16266581,16197096,14314647,16395901,16233792,15713026,16116832,15646746,16381779,16111482,15778306,16165937,15793271,16013432,16215268,14314647,15793271,15301395,16194812,16266581,16013432,15778306,16430932,16013432,16265011,16187641,16381661,15609095,15477650,16116818,15793271,16400499,15793271,16270502,16096830,16187641,15793271,15421266,16094936,15519511,15793271,16426770,16381642,16032662,15468379,15397912,15426083,15793271,15639719,16299168,15793271,16277565,14314647,15565485,15713026,16084313,15636685,16116306,15891357,16084313,15953196,16398744,15519458,14314647,16424058,16211237,16084313,15468379,15568380,15891357,15793271,15636685,16107126,16085403,16419166,15491159,15564307,16221150,16307117,15793271,15793271,15793271,15565485,15793271,15793271,15793271,16221150,14314647,16244538,16307134,15793271,16376782,15860747,16376782,15793271,15565485,16142120,16263602,14314647,16142120,16137522,16308559,16182426,16222122,16107161,16426770,15253194,15961993,15361235,15515359,15573353,15385553,16118595,15750663,16116818,15345884,16419503,15519424,15750663,15299765,15950864,16376782,16041397,15946834,15594296,16255792,16301612,15306456,15461348,15521916,15946834,15628919,15521916,14492168,16116832,16376782,16244538,16050175,15603296,15970190,15519517,15527308,15644562,15650970,15527308,16299587,16419166,15385035,16138136,15302734,16425364,15349114,15877749,16300020,15491159,16116854,16101468,16424945,16123026,15302622,16296887,15621245,15649199,15976127,16142120,15338446,15841996,16406450,16142120,16419346,15338446,15418950,16089403,16101582,16266581,15477602,15338446,15967572,16085403,16266581,16266581,16375466,16397281,15748007,15609095,16397053,16375466,16194812,16116953,16266581,16406366,16083671,16397053,16232729,15360927,15572010,15572010,16193282,15572010,15895704,15895704,15572010,15419823,14971705,15594747,15519472,15646229,15594747,15594747,16157187,16115168,15834886,15594747,16157187,16422648,16035120,16323686,16035120,16267518,16323686,15856889,15890925,16283654,16204980,15856889,15856889,15545409,15856889,16056557,16096830,16297765,15890407,16056557,16111482,15890407,16084175,16261624,15331340,16084175,15890407,16088936,16258615,15764357,16059552,15890407,16424738,15580990,16297085,16140026,15519458,15842031,16129543,16129543,16122519,16425141,15966159,16399988,15572044,16107161,16426770,15625223,15475055,15570251,15720101,16107161,16258786,16225627,16203962,16246122,15564307,15564307,15506175,16084313,16425343,16084313,16282308,15506175,16084313,15712411,15901687,16107161,16233792,15458127,16424856,15597614,15481272,15458127,15481272,16140950,16246122,15584320,16317847,15458127,16116869,15481272,16084313,16299168,16108382,16015427,15481272,15597614,16108382,16304243,15827317,16391945,15398719,15458127,16015427,16211979,15881144,16145806,16108382,15827317,15300599,15271888,15827317,15271888,15371151,16084561,15747009,15271888,16140950,15491360,15904499,15271888,16419272,16266340,15294642,15827317,16339269,16108382,15361021,16234732,16300613,15912093,16084561,15299111,16262442,16294414,15328957,15904499,16116818,15970190,15842031,16266581,16140950,15398719,15519472,16203962,15253194,15527308,16397053,15856889,15603296,16101468,16084313,16116854,15628603,15597614,16422648,16233792,15946834,16258558,16084313,16397053,15649199,15564307,15597614,16304243,15946834,16084313,16084313,15729700,15564307,15360927,16425141,16015427,15481272,15827317,16375466,15827317,16085403,16297765,16225627,16426770,15827317,16193282,16301612,15827317,16426770,16375466,15481272,15481272,15646229,15481272,14971705,16145806,15570251,15834886,16194812,15747009,15621245,15961993,16084561,15349114,15636685,16084561,16267518,15594747,16050175,15594747,16115168,15877749,15594747,16096830,16339269,15890407,15545409,16033788,16376782,15764357,16041397,15594747,16376782,15890407,15300599,15895704,15890407,15895704,16118595,15331340,15609095,15890407,15712411,15338446,15338446,15966159,15299765,15471518,16425364,15338446,16266340,15271888,16258786,15271888,15271888,16299587,15271888,15515359,16296887,16129543,16297085,16111482,15418950,16300020,16129543,16204980,16419272,15345884,16123026,16157187,16266581,16107161,15302622,16116953,15477602,16140026,16056557,15385553,15299312,15904499,16107161,16258615,15328957,16299168,15371151,16116869,16262442,16282308,16419346,15361235,15491159,15650970,15475055,15720101,15841996,15572010,15625223,15748007,15890407,15904499,16283654,16085403,16246122,16246122,15584320,15621245,15890407,15545409,15328957,15573353,15564307,16258786,15877749,15564307,15890407,15904499,16232729,16425343,15299312,15570251,15349114,15306456,15338446,15890407,16424738,15338446,15338446,15827317,16282308,15572010,15827317,15299111,15572010,15572010,15572010,15477602,15300599,15302622,15827317,16115168,16255792,15827317,16300613,15294642,16406366,15418950,16096830,15747009,16261624,16244538,16116869,16419346,16123026,16050175,15946834,16297765,15912093,16041397,15946834,15967572,16116953,16422648,15398719,16425364,15491360,16202171,16056557,16056557,16084175,15764357,16084175,15649199,16118595,16424856,16204980,16435351,16111482,16266581,16267518,16101468,16266581,16400037,16266340,15650970,16266581,16426770,16266581,16300020,15475055,16301612,16116854,16296887,16419166,15950864,16403502,16084561,16089403,16084561,15519424,16323686,16116818,16426770,15519511,16406450,16211979,16323686,16083671,15750663,16233792,15750663,16142120,16142120,16145806,16035120,16430232,16116832,16376782,16035120,15842031,15970190,16375466,16088936,16376782,14492168,16375466,16294414,15515359,16084313,16084313,16084313,16304243,16194812,16138136,16297085,15966159,16157187,15895704,16157187,16129543,15253194,15302734,15895704,16129543,16397053,16084313,16140026,16258615,16397053,15841996,15609095,14971705,16419272,15441430,15891227,15441430,16413055,16422648,15475082,15891227,16139528,15903804,15441430,15595074,16035120,16129543,15903804,15595074,16413055,16129543,16035120,16175641,15877749,16116818,15827317,16175641,16204980,16145806,16175641,15712411,15901687,13986185,15827317,15441430,16233792,15521916,15521916,15595074,15595074,15595074,15371151,15416220,15827317,15595074,15604767,16175641,15827317,15398719,14969178,15604767,15416220,15834886,14969178,15595074,16375466,16140026,16301612,15595074,15890407,15595074,13278160,14969178,15595074,15746434,15628603,15778870,16096830,14969178,15628919,16246173,15256584,15246246,15199988,16434331,15883288,15299111,15515359,15595074,15595074,15595074,15296256,15378686,16425343,16213470,16193883,16426770,16198733,15572010,15595074,15595074,16375466,15416220,15519458,15378686,15441449,15719770,15256584,16041397,16257303,15966159,16197047,16399988,15572010,15890407,15595074,16214244,15595074,15595074,15246246,16426770,14542485,16405818,16213470,15285691,15534008,15443404,16300020,15246246,15595074,15595074,15419823,15595074,15369765,15578022,15443404,15604767,15443404,15572010,15443404,16177932,16061066,15572010,16225416,15534008,14969178,16297085,16334983,15202492,15988304,16177932,15890407,9238528,16424945,15994422,16194569,15378686,15990809,15345305,15441449,16234869,15276945,15595074,15890407,15883142,15461348,15604767,15584320,16177932,15595074,15397892,15595074,16177932,15595074,15632328,15747009,15388381,15595074,15237104,15994422,16234869,15378686,15595074,15237104,16213470,16244538,15346247,15256584,15199988,14542485,15595074,15604767,15296256,15595074,15595074,15778870,14969178,16298324,15429632,15621245,15416220,15954409,16234869,16257252,15639895,15595074,16049074,16257252,15531030,16431553,16413055,14542485,16239307,15595074,15386706,16061066,16239307,15276945,16413055,14542485,15246246,15256584,16035495,16234869,9238528,15482427,16049036,12284918,16450441,13602830,16239307,15261387,15504420,15310639,15649596,15931142,16134214,16213470,16269779,15292816,15803831,16134876,12284918,15990434,16049036,16257252,14315672,15990434,16140950,16269779,15644562,15990507,16354162,15511478,15544727,15297929,15276945,16376782,15978625,16134876,15300823,16065775,15580990,16269779,16376782,15239718,16269779,14315672,12284918,15990434,14315672,15843365,16114690,12284918,15990434,16131449,15511478,14315672,15309353,15887237,15880036,15332272,16049036,12284918,15741766,16098076,16068554,15843365,16403502,15988542,16354954,15458127,16068554,15860650,16049036,12284918,16131449,15458127,15481272,15639757,15458127,15481272,15748007,15458127,16269126,15481272,16204819,15527308,15481272,16185182,15595074,16157187,16191459,15639757,16228368,15519472,16157187,16163758,16191459,15639757,15595074,16185182,15527308,15649199,15639757,16068554,15490981,16140950,16068554,15545497,16114690,16054807,16122519,16084175,16108382,16084175,16108382,16269882,16108382,16056557,15447810,16056557,15423535,16424856,16108382,16305752,15361235,16305752,16163758,16298367,15891227,15420015,15378686,16266581,15604767,16257252,15644562,15490981,15903804,15378686,16266581,15336535,15378686,16083671,15378686,15336535,15604767,15903804,16257252,16266581,12747475,16257252,15841996,15904499,16424856,12747475,16266581,16425141,16096830,15477602,15990434,15573339,15604767,15247597,15891227,15877749,16305752,15595074,15247597,15595074,15584320,15628919,15247597,16305752,15477641,15247597,15990434,15595074,16339269,14492168,16130565,15603296,15595074,15595074,15595074,15416220,15990434,15604767,15595074,15595074,15759398,15759398,13163949,16035120,15595074,15595074,15416220,15416220,16035120,15949451,16211979,15594296,15269965,15564307,15759398,15564307,15990434,16107161,15506175,16233712,16272144,16107161,15604767,16233712,16173613,16107161,15949451,15416220,15883142,15576775,16272144,15386706,15506175,15759398,15195049,15910656,15420718,15988542,16107161,16228125,15966031,16244538,15966031,16215596,15644209,15302734,15595074,15966031,16214244,15595074,15519458,15521916,15521916,15880036,15398719,15246246,16108382,15595074,16122580,16085403,15246246,16108382,15652939,16221320,16122580,15595074,16084313,15441449,15246246,16108382,14315672,15430398,16084313,15595074,14315672,15441449,15246246,16108382,15595074,14315672,16175641,16084313,15652939,15649199,15652939,16225332,15652939,15966031,15414398,14315672,16175641,15595074,15527308,16122580,16084313,16122580,15595074,16419346,16175641,15527308,16175641,15471518,16122580,15199988,15202492,15827317,16122580,15386814,15827317,15827317,15199988,15827317,16304243,16425343,16268873,15967572,15895704,16420691,15266817,15519511,15895704,15990518,16193883,16194571,15345305,15595074,15595074,15778870,16228931,15595074,15595074,15595074,15595074,15361235,16300613,15778870,16193282,16199552,14969178,16140026,15595074,16084561,15572042,14969178,16199213,15609095,15595074,16084561,15391028,15572010,16253346,16266340,15572010,15545409,15572010,14969178,14969178,15978625,14969178,15360356,14969178,15625223,15572010,16397053,16240897,15239718,16211987,15994422,16397053,15834886,15261387,16129543,16131449,15309353,16234869,16258787,15994422,16142120,16234869,16234869,15729700,16234869,16153967,16228368,16306213,16306213,16177932,16177932,16306213,16177932,16118595,16129543,16004862,15639895,15544488,15660062,16131449,16211987,15580990,16153967,16049036,16049036,16177932,15639757,16202461,15595074,16049036,16434331,15595074,15491360,15639757,15639757,15615019,15544727,16142120,16199977,16238276,16306213,15950864,16119624,15912356,16049036,15441430,15986431,15639757,16054807,15441430,15441430,15595074,15595074,15912093,15748007,15371151,15576619,16269126,15458095,15719770,15595074,16297034,15860650,16375466,15591116,15519472,16375466,16114690,15336547,15458095,16219798,15441430,16119624,15306456,16354853,15336547,16308812,15336547,15595074,16132458,16298324,15458127,16283654,16116832,16297085,15336547,15458095,16114690,15595074,15336535,15458127,15458127,15458095,12747475,12747475,15595074,15633625,16293219,15336535,15458127,15904499,16061852,16122580,16122580,15398719,16122580,16122580,16122580,16122580,16375466,16375466,15584320,15649199,14969178,15386660,16306213,16306213,15628603,15515751,16306213,13986185,15346247,14969178,16234732,15331340,15652939,15652939,16306213,15652939,15652939,15481272,15481272,15481272,15481272,16261624,15990809,15534094,16232729,16056557,16056557,16193927,16269779,16269779,16202171,15491360,15597614,15479315,15345884,16257303,15597614,16269779,16220434,16269779,15712411,16195843,16195843,16089403,14492168,16400396,15475082,16419166,16294414,15302734,15475055,16277682,15302730,16425343,16234869,15378686,15378686,15636685,16417251,16234869,16211979,15521916,15378686,16234869,15521916,15386706,15378686,16234869,16175641,16175641,16175641,16199918,16298324,15419823,16375466,16431553,16175641,16193883,16283654,15954409,15294642,15890925,16375466,15466578,16425141,16435351,15874634,16211987,16211987,16193613,16234522,16267518,16240897,16269882,15474889,16245135,16253346,16203962,15360356,16132458,16136607,15206918,16134214,16101582,15731191,15391028,15544727,16228931,16251087,16116121,15573353,16339269,15298621,16134739,16199977,15729169,16251451,15843365,16298367,13602830,15978625,15292816,15650970,15843365,15269965,15818944,16228368,15386814,15202492,15247597,15247597,15300825,15239718,14229868,15247597,16173613,15385035,16054807,15309353,16308812,12777586,16085403,15491159,15299111,16130565,15247597,15544488,15398719,16353856,16214244,16413055,16257252,15300823,16257252,16419346,16257252,16400396,14969178,14969178,16300613,16413055,15491383,15759398,15573339,15827317,14969178,15649199,16413055,16304243,16101468,16157187,16425364,16157187,16413055,15827317,15759398,15827317,14969178,15827317,15759398,16419272,15759398,15597614,15378686,15378686,15378686,15628919,15891227,16375466,15082216,16195843,16417251,15378686,16134876,16375466,16195843,15331340,15597614,15712411,16141002,16353856,16234522,16134876,16300613,15628603,15082216,16294414,16239307,15891227,15887237,15652939,16203962,16193927,16202171,16239307,16134739,15652939,15475082,16239307,15231542,16425343,16061066,16251451,16272144,15466578,15652939,15386660,16298324,15652939,15842031,15990809,16272144,15387482,15196891,15287122,16085403,16061066,13602830,16130565,16101468,16199977,15479315,16245135,16116121,16208485,16056557,16253346,16056557,15954409,16354020,15346247,16354162,16400396,15491383,15890925,16419272,15534094,16267518,16173613,15398719,16425364,16193613,16308812,16357697,13986185,16228931,14492168,12777586,16089403,15506175,15506175,15386814,15391028,16211979,15573353,15387395,16193883,15475055,15521916,15302734,16419166,15481272,15309353,16298367,15521916,16431553,15481272,15239718,15874634,15481272,16261624,15481272,12747475,12747475,16435351,14971705,12747475,15430398,12747475,16397053,15247597,15247597,15269965,15247597,15299111,15485655,16397053,15247597,15294642,14969178,15491159,16306213,16175641,14969178,15299312,16306213,16234732,16202460,15386706,16306213,16175641,16175641,15477602,16306213,15649199,16175641,16419346,16234869,16118595,14969178,16234869,15903463,16234869,15577701,16199918,16234869,15751833,15360356,16294724,15491360,16122580,16132458,16298666,16136607,15649596,16228368,14969178,16400396,14969178,16304243,15741766,15544727,15729169,15731191,15345884,16122580,16277682,15300823,15419823,14969178,16134214,16282308,15298621,15978625,16220434,15843365,15474889,15206918,16122580,16101582,15827317,16177932,15636685,15827317,16177932,15827317,16177932,16122519,16240897,16269779,16269779,15827317,16108382,16108382,15565517,16122580,16140950,16177932,16122580,15202492,16269779,16054807,16425141,16140950,15843365,16108382,16269882,15302730,16202461,16108382,16413055,16157187,16413055,15300825,16211987,16098076,16413055,16211987,15292816,15759398,16269779,16122580,16232729,16339269,16251087,16361866,15385035,16157187,15515751,16214244,15759398,16413055,15764357,15544488,15420015,16283654,15650970,15594296,16134867,16134867,15584320,15841996,14229868,15883142,15573339,16257252,16257303,16450441,16255792,15759398,16083671,16257252,16361866,15759398,16257252,15970190,13602830,15475082,16207296,16261624,15595074,16272144,15595074,15990809,16435351,15345884,15572010,15572010,15572010,15990434,15595074,15239718,15603296,16397281,16141002,15572010,15629799,15309353,16145806,15988542,15338446,16272144,14971705,15990434,16376782,16258797,15338446,16197047,16376782,15629822,15990434,15990434,15580990,16129543,16400037,16129543,15842031,15584320,15595074,15338446,15595074,16194812,15595074,15195049,15990518,15272899,15880026,15595074,16193927,15513474,16397053,16372797,15949451,15196891,16397053,16372797,15880033,15949451,15398719,15597614,15595074,16317847,15595074,16375466,15976127,16375466,16193282,16431553,15747009,15378686,15378686,16115168,15729700,15592807,16096830,16371047,16245135,16298367,15597614,15378686,15378686,15595074,15375611,15519511,16371047,15595074,15466578,15595074,15595074,16061066,15300599,16301612,16253346,15594747,16299587,15594747,16430232,15594747,15594747,15887497,15595074,15595074,15887497,16061066,15299765,15577701,16194569,15931142,15387395,15895704,15895704,15954409,15595074,15595074,15649199,15595074,15595074,16298324,15491383,16300613,16035495,16211987,15576619,16059552,15609095,15271888,16211987,15271888,16393485,15572042,16393485,15271888,15545409,15271888,15595074,15595074,16400396,15595074,15595074,15458095,16323686,16323686,15458095,15961993,15458095,15458095,16050175,15443404,15385553,15843365,16400396,15443404,16116953,15843365,15841996,15467478,15298621,15443404,15644562,15443404,15531030,15385035,16246173,15490981,15328957,16049931,15632328,16197323,15912356,15206918,16399988,16199552,16339269,15595074,14229868,15397912,15615019,16413055,16413055,15636685,16413055,15595074,15253194,15519517,15595074,16197330,16413055,15595074,15877749,15595074,16115479,15595074,15573353,15883288,16136607,15533937,16194571,15292816,15402927,15910656,16049074,16219798,13163949,15429039,15534094,15300823,16297034,15336944,16262442,16041397,15751833,16101582,15595074,16199213,16299168,15595074,16116832,15299111,15515359,15390421,16240897,15729169,15418950,16138136,16054807,16434331,15628919,16142120,15386814,16142120,15990507,16424945,16238276,16173613,15544727,16085403,16405818,16132458,15595074,15299545,16098076,15595074,16403502,15628603,15504420,13278160,16267518,15595074,15573339,15420718,16426770,16450441,16426770,15880036,16266340,12777586,15300825,15328874,13986185,15595074,15195049,15990434,15595074,16298367,15300823,15580990,15990434,15880026,15573353,16141002,15636685,16035120,15533937,15990518,15595074,16272144,15300825,16035120,15196891,16049931,16297034,15990434,15592807,15961993,16399988,15414398,16272144,15595074,16262442,15475082,15595074,16194812,15880033,15595074,15386814,15420718,16050175,13278160,16238276,15328874,16301612,15628919,16298324,16041397,15603296,15420734,15595074,15573339,15595074,15990809,16266340,15747009,16207296,15402927,16246173,16261624,15595074,15458127,16194571,15388381,15729700,16219798,15458127,16299587,15584320,15458127,15595074,15398719,15628603,15458127,15300599,15976127,16199552,16430232,13163949,16299168,16400037,15595074,15595074,15595074,15595074,13986185,15515359,16101582,15387395,16085403,15346247,15534094,15466578,15513474,16317847,15418950,15595074,15877749,15595074,15595074,16435351,16253346,15595074,12777586,15910656,15577701,16173613,15644562,15253194,15931142,15595074,16258797,15595074,16211987,16431553,15385553,16403502,16035495,16211987,16130565,15595074,16424945,14971705,15375611,15633625,15595074,15328957,16245135,15970190,16397281,15595074,15595074,15595074,15595074,16061066,16059552,16061066,16116953,15595074,15834886,15545409,15595074,15595074,15629822,15629799,15595074,15531030,16204953,15912356,15206918,16197047,16197330,15519511,16116832,16300613,15474889,16127449,15632328,16127449,16405818,15443404,15443404,15471518,16136607,14229868,16115479,15443404,15751833,13602830,15443404,15572042,15842031,15843365,16434331,15841996,15843365,16197323,16049036,15887497,15299765,16194569,16132458,15390421,15467478,15660062,15615019,16115168,15883288,15298621,16049036,16049036,15954409,15887497,15397912,15345884,15336944,15544727,15649199,16240897,16049036,15491383,16049074,15990507,16054807,15490981,16339269,16267518,15576619,16138136,16098076,16096830,15729169,16193927,15572010,15572010,15572010,16193282,15595074,15504420,15988542,15572010,15595074,15299545,15595074,15338446,15967185,15272899,15429039,16199213,15519517,15385035,15595074,15519472,15309353,15338446,15880036,15338446,15239718,15990434,16450441"
      val diary_level1 = sc.sql(
        s"""
           |select diary_id,explode(split(level1_ids,';')) level1_id from diary_feat
           |where diary_id in (${diary_queue})
         """.stripMargin
      )
      diary_level1.show()
      println(diary_level1.count())

      //胸部日记id
      val cid_xiong = diary_level1.rdd.filter(_.getAs("level1_id")=="7")
      cid_xiong.collect().foreach(println)

      //计算各类别日记的数量
      val level1_count = diary_level1.rdd.map(x => (x(1).toString)).map(level1 => (level1,1)).reduceByKey((a,b) => a+b).sortBy(_._2,false).toDF("level1_id","count")
      level1_count.show()
      level1_count.createOrReplaceTempView("tmp")
      val level1_name = sc.sql(
        s"""
           |select a.level1_id,a.count,b.level1_name from tmp a
           |left join (select distinct level1_id,level1_name from online.bl_tag_hierarchy_detail where partition_date = '${stat_date}') b
           |on a.level1_id = b.level1_id order by a.count desc
         """.stripMargin
      )
      level1_name.show()

      sc.stop()

    }
  }

}